@@ -34,6 +34,7 @@
 G_BEGIN_DECLS
 
 #define NETK_APP_WINDOW_EVENT_MASK (PropertyChangeMask | StructureNotifyMask)
+#define NETK_MAX_TITLE_LENGTH   255
 
 #define NETK_STOCK_MAXIMIZE     "gtk-zoom-100"
 #define NETK_STOCK_UNMAXIMIZE   "gtk-zoom-out"
@@ -96,6 +97,7 @@ void p_netk_change_viewport (Screen * screen, int x, int y);
 Window p_netk_get_group_leader (Window xwindow);
 char *p_netk_get_session_id (Window xwindow);
 int p_netk_get_pid (Window xwindow);
+char *p_netk_get_client_machine(Window xwindow);
 char *p_netk_get_name (Window xwindow);
 char *p_netk_get_res_class_utf8 (Window xwindow);
 void p_netk_get_wmclass (Window xwindow, char **res_class, char **res_name);
@@ -138,6 +140,8 @@ void p_netk_get_window_position (Screen * screen, Window xwindow, int *xp,
 void p_netk_set_icon_geometry (Window xwindow, int x, int y, int width,
                                int height);
 
+gboolean p_netk_get_icon_geometry (Window xwindow, int* x, int* y, int* width, int* height);
+
 /* p_netk_set_dock_type_hint() kept for backward compat */
 #define p_netk_set_dock_type_hint (w) \
         p_netk_set_type_hint (w, NETK_WINDOW_DOCK)
