@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 2003 Benedikt Meurer <benedikt.meurer@unix-ag.uni-siegen.de>
+ * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2003-2004 Olivier Fourdan <fourdan@xfce.org>
  * All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -36,6 +37,9 @@
 #include <X11/Xmd.h>
 
 G_BEGIN_DECLS
+
+#ifndef XFCE_DISABLE_DEPRECATED
+
 /*
  * Tray icons can send "opcodes" to the system tray. These are X client
  * messages, sent with NoEventMask, a message_type of _NET_SYSTEM_TRAY_OPCODE,
@@ -47,6 +51,7 @@ G_BEGIN_DECLS
 typedef struct _XfceSystemTray XfceSystemTray;
 typedef struct _XfceSystemTrayClass XfceSystemTrayClass;
 
+#define XFCE_TYPE_SYSTEM_TRAY       (xfce_system_tray_get_type())
 #define XFCE_SYSTEM_TRAY(obj)						\
 	G_TYPE_CHECK_INSTANCE_CAST(obj, xfce_system_tray_get_type(),	\
 			XfceSystemTray)
@@ -105,32 +110,34 @@ struct _XfceSystemTrayClass
 {
     GObjectClass parent;
 
-    void (*icon_docked) (XfceSystemTray *, GtkWidget *);
-    void (*icon_undocked) (XfceSystemTray *, GtkWidget *);
-    void (*selection_cleared) (XfceSystemTray *);
-    void (*message_new) (XfceSystemTray *, GtkWidget *, guint, guint,
-			 const gchar *);
-    void (*message_clear) (XfceSystemTray *, GtkWidget *, guint);
+    void (*icon_docked) (XfceSystemTray *tray, GtkWidget *item);
+    void (*icon_undocked) (XfceSystemTray *tray, GtkWidget *item);
+    void (*selection_cleared) (XfceSystemTray *tray);
+    void (*message_new) (XfceSystemTray *tray, GtkWidget *item, guint id, guint timeout,
+			 const gchar *text);
+    void (*message_clear) (XfceSystemTray *tray, GtkWidget *item, guint id);
 };
 
 /* get XfceSystemTray error source identifier */
-extern GQuark xfce_system_tray_error_quark (void);
+GQuark xfce_system_tray_error_quark (void);
 
 /* get XfceSystemTray object type identifier */
-extern GType xfce_system_tray_get_type (void);
+GType xfce_system_tray_get_type (void);
 
 /* create a new system tray */
-extern XfceSystemTray *xfce_system_tray_new (void);
+XfceSystemTray *xfce_system_tray_new (void);
 
 /* register a system tray for a specific screen */
-extern gboolean xfce_system_tray_register (XfceSystemTray *,
-					   Screen *, GError **);
+gboolean xfce_system_tray_register (XfceSystemTray *tray,
+					   Screen *screen, GError **error);
 
 /* unregister a system tray */
-extern void xfce_system_tray_unregister (XfceSystemTray *);
+void xfce_system_tray_unregister (XfceSystemTray *tray);
 
 /* check if a system tray is already running for the screen */
-extern gboolean xfce_system_tray_check_running (Screen *);
+gboolean xfce_system_tray_check_running (Screen *screen);
+
+#endif /* !XFCE_DISABLE_DEPRECATED */
 
 G_END_DECLS
 #endif /* !__HAVE_XFCE_SYSTEM_TRAY_H__ */
